### Name: DPdensity
### Title: Semiparametric Bayesian density estimation
### Aliases: DPdensity DPdensity.default
### Keywords: models

### ** Examples

## Not run: 
##D     ####################################
##D     # Univariate example
##D     ####################################
##D 
##D     # Data
##D       data(galaxy)
##D       galaxy<-data.frame(galaxy,speeds=galaxy$speed/1000) 
##D       attach(galaxy)
##D 
##D     # Initial state
##D       state <- NULL
##D 
##D     # MCMC parameters
##D 
##D       nburn<-10
##D       nsave<-100
##D       nskip<-10
##D       ndisplay<-50
##D       mcmc <- list(nburn=nburn,nsave=nsave,nskip=nskip,ndisplay=ndisplay)
##D 
##D     # Example of Prior information 1
##D     # Fixing alpha, m1, and Psi1
##D 
##D       prior1<-list(alpha=1,m1=rep(0,1),psiinv1=diag(0.5,1),nu1=4,tau1=1,tau2=100)
##D 
##D     # Example of Prior information 2
##D     # Fixing alpha and m1
##D 
##D       prior2<-list(alpha=1,m1=rep(0,1),psiinv2=diag(0.5,1),nu1=4,nu2=4,tau1=1,
##D                    tau2=100)
##D 
##D     # Example of Prior information 3
##D     # Fixing only alpha
##D 
##D       prior3<-list(alpha=1,m2=rep(0,1),s2=diag(100000,1),psiinv2=diag(0.5,1),
##D                    nu1=4,nu2=4,tau1=1,tau2=100)
##D 
##D     # Example of Prior information 4
##D     # Everything is random
##D 
##D       prior4<-list(a0=2,b0=1,m2=rep(0,1),s2=diag(100000,1),psiinv2=diag(0.5,1),
##D                    u1=4,nu2=4,tau1=1,tau2=100)
##D 
##D     # Fit the models
##D 
##D       fit1.1<-DPdensity(y=speeds,prior=prior1,mcmc=mcmc,state=state,status=TRUE)
##D       fit1.2<-DPdensity(y=speeds,prior=prior2,mcmc=mcmc,state=state,status=TRUE)
##D       fit1.3<-DPdensity(y=speeds,prior=prior3,mcmc=mcmc,state=state,status=TRUE)
##D       fit1.4<-DPdensity(y=speeds,prior=prior4,mcmc=mcmc,state=state,status=TRUE)
##D 
##D     # Posterior means
##D       fit1.1
##D       fit1.2
##D       fit1.3
##D       fit1.4
##D 
##D     # Plot the estimated density
##D       plot(fit1.1,ask=FALSE)
##D       plot(fit1.2,ask=FALSE)
##D       plot(fit1.3,ask=FALSE)
##D       plot(fit1.4,ask=FALSE)
##D 
##D     # Plot the parameters (only prior 2 for illustration)
##D     # (to see the plots gradually set ask=TRUE)
##D       plot(fit1.2,ask=FALSE,output="param")
##D 
##D     # Plot the a specific parameters 
##D     # (to see the plots gradually set ask=TRUE)
##D       plot(fit1.2,ask=FALSE,output="param",param="psi1-speeds",nfigr=1,nfigc=2)
##D 
##D     # Extracting the posterior mean of the specific means and covariance matrices 
##D     # (only prior 2 for illustration)
##D       DPrandom(fit1.2) 
##D 
##D     # Ploting predictive information about the specific means and covariance matrices 
##D     # with HPD and Credibility intervals
##D     # (only prior 2 for illustration)
##D     # (to see the plots gradually set ask=TRUE)
##D       plot(DPrandom(fit1.2,predictive=TRUE),ask=FALSE)
##D       plot(DPrandom(fit1.2,predictive=TRUE),ask=FALSE,hpd=FALSE)
##D 
##D     # Ploting information about all the specific means and covariance matrices 
##D     # with HPD and Credibility intervals
##D     # (only prior 2 for illustration)
##D     # (to see the plots gradually set ask=TRUE)
##D       plot(DPrandom(fit1.2),ask=FALSE,hpd=FALSE)
## End(Not run)



